==> lusid_sdk-0.6.68-py2.py3-none-any.whl: lusid/models/property_schema_dto.py <==
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright © 2018 FINBOURNE TECHNOLOGY LTD
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PropertySchemaDto(Model):
    """PropertySchemaDto.

    :param href:
    :type href: str
    :param values:
    :type values: list[~lusid.models.KeyValuePairPropertyKeyFieldSchema]
    """

    _attribute_map = {
        'href': {'key': 'href', 'type': 'str'},
        'values': {'key': 'values', 'type': '[KeyValuePairPropertyKeyFieldSchema]'},
    }

    def __init__(self, href=None, values=None):
        super(PropertySchemaDto, self).__init__()
        self.href = href
        self.values = values

==> lusid_sdk-0.6.285-py2.py3-none-any.whl: lusid/models/property_schema_dto.py <==
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright © 2018 FINBOURNE TECHNOLOGY LTD
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PropertySchemaDto(Model):
    """PropertySchemaDto.

    :param href:
    :type href: str
    :param values:
    :type values: list[~lusid.models.KeyValuePairOfPropertyKeyToFieldSchema]
    """

    _attribute_map = {
        'href': {'key': 'href', 'type': 'str'},
        'values': {'key': 'values', 'type': '[KeyValuePairOfPropertyKeyToFieldSchema]'},
    }

    def __init__(self, href=None, values=None):
        super(PropertySchemaDto, self).__init__()
        self.href = href
        self.values = values
